from setuptools import setup, find_packages

setup(
    name='oii',
    version='0.12',
    author='yeyu',
    author_email='zwgmlr3@outlook.com',
    description='myself odoo tools',
    packages=find_packages(),
)
